render_to_string

Function render_to_string 

pub fn render_to_string(
    context: &Context,
    graph: &Graph,
    format: Format,
) -> Result<String, GraphvizError>
Renders a graph to a string with the specified format.

For binary formats, the result is base64-encoded.

Arguments

  • context - The GraphViz context
  • graph - The graph to render
  • format - The output format

Returns

A Result containing the rendered string or an error